@@ -31,7 +31,7 @@ doJob = function(reg, ids, multiple.result.files, disable.mail, first, last, arr
 
   if (!is.na(array.id)) {
     # FIXME better send error to database here, we don't see those errors on the master :(
-    array.id = asInt(array.id, lower = 1L, upper = length(ids))
+    array.id = asInt(as.integer(array.id), lower = 1L, upper = length(ids))
     messagef("Processing array id %s", array.id)
     ids = ids[array.id]
   }
