@@ -5,9 +5,11 @@
 #'   Ids of jobs.
 #'   Default is all jobs.
 #' @return [\code{character}]. Vector of file paths to log files.
+#' @family debug
 #' @export
 getLogFiles = function(reg, ids) {
-  checkArg(reg, "Registry")
+  checkRegistry(reg)
+  syncRegistry(reg)
   if (missing(ids))
     ids = getJobIds(reg)
   else
