@@ -23,10 +23,12 @@
 #'   Default is \code{604800} (one week).
 #' @param stop.on.error [\code{logical(1)}]\cr
 #'   Immediately return if a job terminates with an error? Default is \code{FALSE}.
+#' @template arg_progressbar
 #' @return [\code{logical(1)}]. Returns \code{TRUE} if all jobs terminated successfully
 #'   and \code{FALSE} if either an error occurred or the timeout is reached.
 #' @export
-waitForJobs = function(reg, ids, sleep = 10, timeout = 604800, stop.on.error = FALSE) {
+waitForJobs = function(reg, ids, sleep = 10, timeout = 604800, stop.on.error = FALSE,
+  progressbar = TRUE) {
   checkRegistry(reg)
   syncRegistry(reg)
   if (missing(ids)) {
@@ -42,6 +44,7 @@ waitForJobs = function(reg, ids, sleep = 10, timeout = 604800, stop.on.error = F
     stop("Argument 'sleep' must be finite")
   assertNumber(timeout, lower = sleep)
   assertFlag(stop.on.error)
+  assertFlag(progressbar)
 
   n = length(ids)
   if (n == 0L)
@@ -50,7 +53,7 @@ waitForJobs = function(reg, ids, sleep = 10, timeout = 604800, stop.on.error = F
   batch.ids = getBatchIds(reg, "Cannot find jobs on system")
   i = 1L
 
-  bar = makeProgressBar(min = 0L, max = n, label = "Waiting                  ")
+  bar = getProgressBar(progressbar, min = 0L, max = n, label = "Waiting                  ")
   on.exit(bar$kill())
 
   repeat {
@@ -75,8 +78,11 @@ waitForJobs = function(reg, ids, sleep = 10, timeout = 604800, stop.on.error = F
       # check if there are still jobs on the system and none has mystically disappeared
       # NOTE it seems like some schedulers are "laggy", we should not do this operation
       # in the first loop w/o a sleep
-      if(!length(dbFindOnSystem(reg, ids, batch.ids = batch.ids)))
+      if (length(dbFindOnSystem(reg, ids, batch.ids = batch.ids)) == 0L) {
+        if (length(dbFindDisappeared(reg, ids, batch.ids = batch.ids)) > 0L)
+          bar$error(stop("Some jobs disappeared, i.e. were submitted but are now gone. Check your configuration and template file."))
         return(stats$error == 0L)
+      }
     }
 
     if (is.finite(timeout) && now() > timeout) {
